==> haskell-wai-middleware-static-0.9.3-173-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-middleware-static
version:              0.9.3
visibility:           public
id:                   wai-middleware-static-0.9.3-BDy5dT2lIB0BVMlhipMd9w
key:                  wai-middleware-static-0.9.3-BDy5dT2lIB0BVMlhipMd9w
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  b02125b89379a55c3a78148e4ed6c12a
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.3-BDy5dT2lIB0BVMlhipMd9w
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-UlhuRwgBIQ75TYKUiV4JF
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-AZVBBwcxRiC1GhqzQ4shyQ directory-1.3.7.1
    expiring-cache-map-0.0.6.1-7itJS0ziD8k7kc3F85bEM3 filepath-1.4.2.2
    http-types-0.12.4-5kbj0Cv0rp8HNRwQfelhRA
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh text-2.0.2 time-1.12.2
    wai-3.2.4-HbGzj3ODjKy9gf24pBgAvG

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-middleware-static-0.9.3-174-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-middleware-static
version:              0.9.3
visibility:           public
id:                   wai-middleware-static-0.9.3-4LIizEyI6JcHr4wwAwoETl
key:                  wai-middleware-static-0.9.3-4LIizEyI6JcHr4wwAwoETl
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  5a748bf31aa5f3bb6a57dc6445e34ce4
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.3-4LIizEyI6JcHr4wwAwoETl
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-UlhuRwgBIQ75TYKUiV4JF
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-AZVBBwcxRiC1GhqzQ4shyQ directory-1.3.7.1
    expiring-cache-map-0.0.6.1-7itJS0ziD8k7kc3F85bEM3 filepath-1.4.2.2
    http-types-0.12.4-5kbj0Cv0rp8HNRwQfelhRA
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh text-2.0.2 time-1.12.2
    wai-3.2.4-HbGzj3ODjKy9gf24pBgAvG

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
